summaryrefslogtreecommitdiffstats
path: root/test
diff options
context:
space:
mode:
authorHugo Landau <hlandau@openssl.org>2023-05-03 19:01:12 +0100
committerTomas Mraz <tomas@openssl.org>2023-05-29 08:51:12 +0200
commit6084e04b25378a4590798a034633e90791cf74a3 (patch)
treea79d4cc002245341a7fc1f0654e879f34568afd6 /test
parentf8503ede86115b67e1552cf332d53fe43f0cb5bd (diff)
QUIC: Rename SSL_tick, SSL_get_tick_timeout
Reviewed-by: Matt Caswell <matt@openssl.org> Reviewed-by: Tim Hudson <tjh@openssl.org> Reviewed-by: Tomas Mraz <tomas@openssl.org> (Merged from https://github.com/openssl/openssl/pull/20879)
Diffstat (limited to 'test')
-rw-r--r--test/helpers/quictestlib.c2
-rw-r--r--test/quic_client_test.c2
-rw-r--r--test/quic_multistream_test.c2
-rw-r--r--test/quic_tserver_test.c2
-rw-r--r--test/quicapitest.c2
-rw-r--r--test/quicfaultstest.c14
6 files changed, 12 insertions, 12 deletions
diff --git a/test/helpers/quictestlib.c b/test/helpers/quictestlib.c
index c33518805d..79f25dc1eb 100644
--- a/test/helpers/quictestlib.c
+++ b/test/helpers/quictestlib.c
@@ -268,7 +268,7 @@ int qtest_create_quic_connection(QUIC_TSERVER *qtserv, SSL *clientssl)
* be done in a real application.
*/
if (!clienterr && retc <= 0)
- SSL_tick(clientssl);
+ SSL_handle_events(clientssl);
if (!servererr && rets <= 0) {
ossl_quic_tserver_tick(qtserv);
servererr = ossl_quic_tserver_is_term_any(qtserv);
diff --git a/test/quic_client_test.c b/test/quic_client_test.c
index 81b21fda3a..e3fe678edd 100644
--- a/test/quic_client_test.c
+++ b/test/quic_client_test.c
@@ -148,7 +148,7 @@ static int test_quic_client(void)
* blocking but this is just a test.
*/
OSSL_sleep(0);
- SSL_tick(c_ssl);
+ SSL_handle_events(c_ssl);
}
testresult = 1;
diff --git a/test/quic_multistream_test.c b/test/quic_multistream_test.c
index f846a412b5..3f56e0baa7 100644
--- a/test/quic_multistream_test.c
+++ b/test/quic_multistream_test.c
@@ -632,7 +632,7 @@ static int run_script_worker(struct helper *h, const struct script_op *script,
ossl_quic_tserver_tick(h->s);
if (thread_idx >= 0 || connect_started)
- SSL_tick(h->c_conn);
+ SSL_handle_events(h->c_conn);
if (thread_idx >= 0) {
/* Only allow certain opcodes on child threads. */
diff --git a/test/quic_tserver_test.c b/test/quic_tserver_test.c
index ae25adc444..eefb5ae743 100644
--- a/test/quic_tserver_test.c
+++ b/test/quic_tserver_test.c
@@ -333,7 +333,7 @@ static int do_test(int use_thread_assist, int use_fake_time, int use_inject)
*/
if (!c_start_idle_test || c_done_idle_test) {
/* Inhibit manual ticking during idle test to test TA mode. */
- SSL_tick(c_ssl);
+ SSL_handle_events(c_ssl);
}
ossl_quic_tserver_tick(tserver);
diff --git a/test/quicapitest.c b/test/quicapitest.c
index 25594ca061..957736eb9d 100644
--- a/test/quicapitest.c
+++ b/test/quicapitest.c
@@ -91,7 +91,7 @@ static int test_quic_write_read(int idx)
msglen, &numbytes)))
goto end;
ossl_quic_tserver_tick(qtserv);
- SSL_tick(clientquic);
+ SSL_handle_events(clientquic);
/*
* In blocking mode the SSL_read_ex call will block until the socket is
* readable and has our data. In non-blocking mode we're doing everything
diff --git a/test/quicfaultstest.c b/test/quicfaultstest.c
index 1a0f41af80..c9b00ab280 100644
--- a/test/quicfaultstest.c
+++ b/test/quicfaultstest.c
@@ -132,7 +132,7 @@ static int test_unknown_frame(void)
goto err;
ossl_quic_tserver_tick(qtserv);
- if (!TEST_true(SSL_tick(cssl)))
+ if (!TEST_true(SSL_handle_events(cssl)))
goto err;
if (!TEST_int_le(ret = SSL_read(cssl, buf, sizeof(buf)), 0))
@@ -145,10 +145,10 @@ static int test_unknown_frame(void)
/*
* TODO(QUIC): We should expect an error on the queue after this - but we
* don't have it yet.
* Note, just raising the error in the obvious place causes SSL_tick() to
* succeed, but leave a suprious error on the stack. We need to either
* allow SSL_tick() to fail, or somehow delay the raising of the error
* until the SSL_read() call.
*/
if (!TEST_int_eq(ERR_GET_REASON(ERR_peek_error()),
SSL_R_UNKNOWN_FRAME_TYPE_RECEIVED))
@@ -339,7 +339,7 @@ static int test_corrupted_data(int idx)
* "lost". We also process the second packet which should be decrypted
* successfully. Therefore we ack the frames in it
*/
- if (!TEST_true(SSL_tick(cssl)))
+ if (!TEST_true(SSL_handle_events(cssl)))
goto err;
/*
@@ -349,7 +349,7 @@ static int test_corrupted_data(int idx)
ossl_quic_tserver_tick(qtserv);
/* Receive and process the newly arrived message data resend */
- if (!TEST_true(SSL_tick(cssl)))
+ if (!TEST_true(SSL_handle_events(cssl)))
goto err;
/* The whole message should now have arrived */
@@ -145,10 +145,10 @@ static int test_unknown_frame(void)
* TODO(QUIC): We should expect an error on the queue after this - but we
* don't have it yet.
- * Note, just raising the error in the obvious place causes SSL_tick() to
- * succeed, but leave a suprious error on the stack. We need to either
- * allow SSL_tick() to fail, or somehow delay the raising of the error
- * until the SSL_read() call.
+ * Note, just raising the error in the obvious place causes
+ * SSL_handle_events() to succeed, but leave a suprious error on the stack.
+ * We need to either allow SSL_handle_events() to fail, or somehow delay the
+ * raising of the error until the SSL_read() call.
*/
if (!TEST_int_eq(ERR_GET_REASON(ERR_peek_error()),